@@ -50,7 +50,7 @@ class Exceptions:
 
 class DLMClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dlm.html#DLM.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/dlm.html#DLM.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dlm/client.html)
     """
 
@@ -66,7 +66,7 @@ class DLMClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dlm.html#DLM.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/dlm.html#DLM.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dlm/client.html#can_paginate)
         """
 
@@ -77,13 +77,13 @@ class DLMClient(BaseClient):
         Description: str,
         State: SettablePolicyStateValuesType,
         PolicyDetails: "PolicyDetailsTypeDef",
-        Tags: Mapping[str, str] = None
+        Tags: Mapping[str, str] = ...
     ) -> CreateLifecyclePolicyResponseTypeDef:
         """
         Creates a policy to manage the lifecycle of the specified Amazon Web Services
         resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dlm.html#DLM.Client.create_lifecycle_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/dlm.html#DLM.Client.create_lifecycle_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dlm/client.html#create_lifecycle_policy)
         """
 
@@ -92,37 +92,37 @@ class DLMClient(BaseClient):
         Deletes the specified lifecycle policy and halts the automated operations that
         the policy specified.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dlm.html#DLM.Client.delete_lifecycle_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/dlm.html#DLM.Client.delete_lifecycle_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dlm/client.html#delete_lifecycle_policy)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dlm.html#DLM.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/dlm.html#DLM.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dlm/client.html#generate_presigned_url)
         """
 
     def get_lifecycle_policies(
         self,
         *,
-        PolicyIds: Sequence[str] = None,
-        State: GettablePolicyStateValuesType = None,
-        ResourceTypes: Sequence[ResourceTypeValuesType] = None,
-        TargetTags: Sequence[str] = None,
-        TagsToAdd: Sequence[str] = None
+        PolicyIds: Sequence[str] = ...,
+        State: GettablePolicyStateValuesType = ...,
+        ResourceTypes: Sequence[ResourceTypeValuesType] = ...,
+        TargetTags: Sequence[str] = ...,
+        TagsToAdd: Sequence[str] = ...
     ) -> GetLifecyclePoliciesResponseTypeDef:
         """
         Gets summary information about all or the specified data lifecycle policies.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dlm.html#DLM.Client.get_lifecycle_policies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/dlm.html#DLM.Client.get_lifecycle_policies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dlm/client.html#get_lifecycle_policies)
         """
 
@@ -130,7 +130,7 @@ class DLMClient(BaseClient):
         """
         Gets detailed information about the specified lifecycle policy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dlm.html#DLM.Client.get_lifecycle_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/dlm.html#DLM.Client.get_lifecycle_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dlm/client.html#get_lifecycle_policy)
         """
 
@@ -138,7 +138,7 @@ class DLMClient(BaseClient):
         """
         Lists the tags for the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dlm.html#DLM.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/dlm.html#DLM.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dlm/client.html#list_tags_for_resource)
         """
 
@@ -146,7 +146,7 @@ class DLMClient(BaseClient):
         """
         Adds the specified tags to the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dlm.html#DLM.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/dlm.html#DLM.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dlm/client.html#tag_resource)
         """
 
@@ -154,7 +154,7 @@ class DLMClient(BaseClient):
         """
         Removes the specified tags from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dlm.html#DLM.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/dlm.html#DLM.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dlm/client.html#untag_resource)
         """
 
@@ -162,14 +162,14 @@ class DLMClient(BaseClient):
         self,
         *,
         PolicyId: str,
-        ExecutionRoleArn: str = None,
-        State: SettablePolicyStateValuesType = None,
-        Description: str = None,
-        PolicyDetails: "PolicyDetailsTypeDef" = None
+        ExecutionRoleArn: str = ...,
+        State: SettablePolicyStateValuesType = ...,
+        Description: str = ...,
+        PolicyDetails: "PolicyDetailsTypeDef" = ...
     ) -> Dict[str, Any]:
         """
         Updates the specified lifecycle policy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dlm.html#DLM.Client.update_lifecycle_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/dlm.html#DLM.Client.update_lifecycle_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dlm/client.html#update_lifecycle_policy)
         """
